@@ -1,9 +1,9 @@
 package WebService::Hooktheory;
 our $AUTHORITY = 'cpan:GENE';
 
-# ABSTRACT: Access to https://www.hooktheory.com
+# ABSTRACT: Access to the Hooktheory API
 
-our $VERSION = '0.01';
+our $VERSION = '0.0101';
 
 use Moo;
 use strictures 2;
@@ -104,11 +104,11 @@ __END__
 
 =head1 NAME
 
-WebService::Hooktheory - Access to https://www.hooktheory.com
+WebService::Hooktheory - Access to the Hooktheory API
 
 =head1 VERSION
 
-version 0.01
+version 0.0101
 
 =head1 SYNOPSIS
 
@@ -131,8 +131,12 @@ C<WebService::Hooktheory> provides access to the L<https://www.hooktheory.com> A
 
 =head2 activkey
 
+Your authorized access key.
+
 =head2 base
 
+The base URL.  Default: https://api.hooktheory.com/v1/
+
 =head1 METHODS
 
 =head2 new()
@@ -155,13 +159,19 @@ Fetch the results given the B<endpoint> and optional B<query> arguments.
 
 =head1 THANK YOU
 
-Dan Book
+Dan Book (DBOOK)
 
 =head1 SEE ALSO
 
+L<https://www.hooktheory.com/api/trends/docs>
+
 L<Moo>
 
-L<https://www.hooktheory.com/>
+L<Mojo::UserAgent>
+
+L<Mojo::JSON::MaybeXS>
+
+L<Mojo::JSON>
 
 =head1 AUTHOR
 
